<?php
namespace BwlFaqManager\Base;

use BwlFaqManager\Helpers\PluginConstants;

/**
 * Class for registering the plugin scripts and styles.
 *
 * @package BwlFaqManager
 */
class Enqueue {



	/**
	 * Frontend script slug.
	 *
	 * @var string $frontend_script_slug
	 */
	private $frontend_script_slug;


	/**
	 * Options array.
	 *
	 * @var array $options
	 */
	private $options = [];
	/**
	 * Constructor.
	 */
	public function __construct() {
		// Frontend script slug.
		// This is required to hook the loclization texts.
		$this->frontend_script_slug = 'baf-frontend';
		$this->options              = PluginConstants::$plugin_options;
	}

	/**
	 * Register the plugin scripts and styles loading actions.
	 */
	public function register() {
		add_action( 'wp_enqueue_scripts', [ $this, 'get_the_styles' ] );
		add_action( 'wp_enqueue_scripts', [ $this, 'get_the_scripts' ] );
	}

	/**
	 * Load the plugin styles.
	 */
	public function get_the_styles() {
		// Register Styles.

		wp_enqueue_style(
            $this->frontend_script_slug,
            BAF_STYLES_ASSETS_DIR . 'frontend.css',
            [],
            BAF_PLUGIN_VERSION
		);

		if ( is_rtl() ) {

			wp_enqueue_style(
				'baf-frontend-rtl',
				BAF_STYLES_ASSETS_DIR . 'frontend_rtl.css',
				[],
				BAF_PLUGIN_VERSION
			);
		}

		$disable_font_awesome = $this->options[ BAF_FONT_AWESOME_STATUS ] ?? 0;

		if ( ! $disable_font_awesome ) {
			wp_enqueue_style(
                'font-awesome',
                BAF_LIBS_DIR . 'font-awesome/font-awesome.min.css',
                [],
                BAF_PLUGIN_VERSION
			);

			wp_enqueue_style(
                'font-awesome-shims',
                BAF_LIBS_DIR . 'libs/font-awesome/v4-shims.min.css',
                [],
                BAF_PLUGIN_VERSION
			);
		}
	}

	/**
	 * Load the plugin scripts.
	 */
	public function get_the_scripts() {

            wp_enqueue_script(
                $this->frontend_script_slug,
                BAF_SCRIPTS_ASSETS_DIR . 'frontend.js',
                [ 'jquery' ],
                BAF_PLUGIN_VERSION,
                true
            );

		// Load frontend variables used by the JS files.
		$this->get_the_localization_texts();
	}

	/**
	 * Load the localization texts.
	 */
	private function get_the_localization_texts() {

		// Localize scripts.
		// Frontend.
		// Access data: BptmFrontendData.version
		wp_localize_script(
            $this->frontend_script_slug,
            'BafFrontendData',
            [
				'ajaxurl'                => esc_url( admin_url( 'admin-ajax.php' ) ),
				'err_faq_category'       => esc_html__( 'Select FAQ Category!', 'bwl-adv-faq' ),
				'err_faq_captcha'        => esc_html__( ' Incorrect Captcha Value!', 'bwl-adv-faq' ),
				'string_total'           => esc_html__( 'Total', 'bwl-adv-faq' ),
				'string_singular_page'   => apply_filters( 'baf_single_string', esc_html__( 'Page !', 'bwl-adv-faq' ) ),
				'string_plural_page'     => esc_html__( 'Pages !', 'bwl-adv-faq' ),
				'string_please_wait'     => esc_html__( 'Please Wait .....', 'bwl-adv-faq' ),
				'string_ques_added'      => esc_html__( 'Question successfully added for review!', 'bwl-adv-faq' ),
				'string_ques_unable_add' => esc_html__( 'Unable to add faq. Please try again!', 'bwl-adv-faq' ),

				'noting_found_text'      => apply_filters( 'baf_search_nothing_found_text', esc_html__( 'Nothing Found!', 'bwl-adv-faq' ) ),
				'found_text'             => apply_filters( 'baf_search_found_text', esc_html__( 'Found', 'bwl-adv-faq' ) ),
				'singular_faq'           => apply_filters( 'baf_search_singular_faq_text', esc_html__( 'FAQ !', 'bwl-adv-faq' ) ),
				'plural_faq'             => apply_filters( 'baf_search_plural_faq_text', esc_html__( 'FAQs !', 'bwl-adv-faq' ) ),

				'next_page'              => esc_html__( 'Next page', 'bwl-adv-faq' ),
				'previous_page'          => esc_html__( 'Previous page', 'bwl-adv-faq' ),
				'pagination_page_number' => esc_html__( 'Page', 'bwl-adv-faq' ),
				'title'                  => BAF_PLUGIN_TITLE,
				'url'                    => BAF_PRODUCT_URL,
				'verified'               => BAF_PRODUCT_VERIFIED_STATUS,
				'disable_schema'         => $this->options[ BAF_FAQ_SCHEMA_STATUS ] ?? 0,
            ]
		);
	}
}
