<?php
namespace BwlFaqManager\Callbacks\AdminAjaxHandlers\Sort;

/**
 * Class for saving category order.
 *
 * @package BwlFaqManager
 */
class SaveCategoryOrderCb {

	/**
	 * Save the category order.
	 *
	 * @return void
	 */
	public function save() {

		if ( ! check_ajax_referer( 'baf_nonce_action', $_REQUEST['_ajax_nonce'] ) ) {
			wp_send_json_error( 'Invalid nonce' );
		}

		if ( ! current_user_can( 'manage_options' ) ) {
			wp_send_json_error( 'Permission denied' );
		}

		$taxonomy = sanitize_text_field( $_REQUEST['taxonomy'] ?? '' );

		if ( ! $taxonomy || ! taxonomy_exists( $taxonomy ) ) {
			wp_send_json_error( 'Invalid taxonomy' );
		}

		$order = json_decode( stripslashes( $_REQUEST['baf_sort_data'] ), true );

		if ( ! $order ) {
			wp_send_json_error( 'Invalid order format' );
		}

		$this->save_term_order_recursive( $order, 0, $taxonomy );

		$post_data['status'] = 1;
		wp_send_json_success( $post_data );
	}

	/**
	 * Recursively save the term order.
	 *
	 * @param array  $items The items to save.
	 * @param int    $parent_id The parent ID.
	 * @param string $taxonomy The taxonomy.
	 *
	 * @return void
	 */
	private function save_term_order_recursive( $items, $parent_id, $taxonomy ) {
		$menu_order = 0;

		foreach ( $items as $item ) {
			$term_id = intval( $item['id'] );
			if ( $term_id <= 0 ) { continue;
			}

			wp_update_term($term_id, $taxonomy, [
                'parent' => $parent_id,
			]);

			global $wpdb;
			$wpdb->update(
				$wpdb->terms,
				[ 'term_order' => $menu_order++ ],
				[ 'term_id' => $term_id ]
			);

			if ( ! empty( $item['children'] ) ) {
				$this->save_term_order_recursive( $item['children'], $term_id, $taxonomy );
			}
		}
	}
}
