<?php
namespace BwlFaqManager\Callbacks\AdminAjaxHandlers;

/**
 * Class TaxonomySortSaveCb
 *
 * @package BwlFaqManager
 */
class TaxonomySortSaveCb {

	/**
	 * Save the sorting data.
	 */
	public function save() {

		if ( ! check_ajax_referer( 'baf_nonce_action', $_REQUEST['_ajax_nonce'] ) ) {
			wp_send_json_error( 'Invalid nonce' );
		}

		if ( ! current_user_can( 'manage_options' ) ) {
			wp_send_json_error( 'Permission denied' );
		}

		global $wpdb;

		$baf_sort_filter_type = sanitize_text_field( $_POST['baf_sort_filter_type'] );
		$baf_term_id          = sanitize_text_field( $_POST['baf_term_id'] );
		$baf_sort_data        = sanitize_text_field( $_POST['baf_sort_data'] );

		switch ( $baf_sort_filter_type ) {
			case 'category':
				update_option( PREFIX_BAF_CAT . $baf_term_id, $baf_sort_data );
				$status = 1;
				break;
			case 'topics':
				update_option( PREFIX_BAF_TOPIC . $baf_term_id, $baf_sort_data );
				$status = 1;
				break;
			case 'all':
				// Save All Sorting Data (menu_order)
				$order   = explode( ',', $baf_sort_data );
				$counter = 0;
				if ( count( $order ) > 0 ) {
					foreach ( $order as $bwl_faq_id ) {

						$wpdb->update( $wpdb->posts, [ 'menu_order' => $counter ], [ 'ID' => $bwl_faq_id ] );
						++$counter;
					}
				}
				$status = 1;
				break;
			default:
				$baf_sort_filter_type = '';
				$status               = 0;
		}

		$post_data['status'] = $status;
		wp_send_json_success( $post_data );

	}
}
