<?php

namespace BwlFaqManager\Callbacks\FrontendAjaxHandlers;

use BwlFaqManager\Helpers\PluginConstants;

/**
 * Class for plugin installation callback.
 *
 * @package BwlFaqManager
 */
class ViewsTrackerCb {

	/**
	 * Save views data.
	 */
	public function save_data() {

		if ( isset( $_REQUEST['faqId'] ) && ! empty( $_REQUEST['faqId'] ) ) {

				// Retrieve user IP address

				$ip = $_SERVER['REMOTE_ADDR'];

				$post_id = $_REQUEST['faqId'];
				$pageId  = $_REQUEST['pageId'];
			// Get voters'IPs for the current post
				$meta_IP = get_post_meta( $post_id, 'baf_views_IP' );

			if ( ! empty( $meta_IP ) ) {

					$baf_views_IP = $meta_IP[0];
			} else {

					$baf_views_IP = [];
			}

				$baf_views_counter = intval( get_post_meta( $post_id, 'baf_views_count', true ) );

			if ( ! $this->has_already_viewed( $post_id ) ) {

					$timestamp = time();

					$baf_views_IP[ $ip ] = $timestamp;

					// Update Data of "baf_likes_data"

					$table_data = [
						'post_id'         => $post_id,
						'page_id'         => $pageId,
						'ip'              => $ip,
						'views_date_time' => date( 'Y-m-d H:i:s', $timestamp ),
					];

					$this->insert_view_data( $table_data );

					// Save IP and increase views count

					update_post_meta( $post_id, 'baf_views_IP', $baf_views_IP );
					update_post_meta( $post_id, 'baf_views_count', ++$baf_views_counter );

					$data = [
						'status' => 1, // count views.
					];
			} else {
				// already viewed.
					$data = [
						'status' => 0,
					];
			}

				echo wp_json_encode( $data );
		}

		die();
	}

	/**
	 * Insert view data.
	 *
	 * @param array $table_data Table data.
	 */
	public function insert_view_data( $table_data = [] ) {

		if ( empty( $table_data ) ) { return '';
		}

		global $wpdb;

		$table_data_type = [
			'%d', // post_id
			'%d', // page_id
			'%s', // ip
			'%s', // like_date_time
		];

		$wpdb->insert( TABLE_BAF_VIEWS_DATA, $table_data, $table_data_type );
	}

	/**
	 * Check if user has already viewed the post.
	 *
	 * @param int $post_id Post ID.
	 *
	 * @return bool
	 */
	public function has_already_viewed( $post_id ) {

		if ( empty( $post_id ) ) {
			return false;
		}

		$repeat_vote_interval = ( isset( PluginConstants::$plugin_options['baf_repeat_vote_interval'] )
		&& is_numeric( PluginConstants::$plugin_options['baf_repeat_vote_interval'] )
		&& PluginConstants::$plugin_options['baf_repeat_vote_interval'] > 0 ) ? PluginConstants::$plugin_options['baf_repeat_vote_interval'] : 120; // = 2 hours

		// Retrieve post views IPs
		$meta_IP = get_post_meta( $post_id, 'baf_views_IP' );

		$baf_vote_count = intval( get_post_meta( $post_id, 'baf_views_count', true ) );

		if ( $baf_vote_count === 0 ) {
				return false;
		}

		if ( ! empty( $meta_IP ) ) {

				$baf_views_IP = $meta_IP[0];
		} else {

			$baf_views_IP = [];
		}

		// Retrieve current user IP
		$ip = $_SERVER['REMOTE_ADDR'];

		// If user has already voted
		if ( in_array( $ip, array_keys( $baf_views_IP ), true ) ) {

			$time = $baf_views_IP[ $ip ];

			$now = time();

			// Compare between current time and vote time

			if ( round( ( $now - $time ) / 60 ) > $repeat_vote_interval ) {

					return false;
			}

			return true;
		}

		return false;
	}
}
