<?php
namespace BwlFaqManager\Callbacks\OptionsPanel\Pages;

use Xenioushk\BwlPluginApi\Api\View\ViewApi;

/**
 * Class for loading the settings page template.
 *
 * @package BwlFaqManager
 * @since: 1.0.0
 * @author: Mahbub Alam Khan
 */
class AddonsPageCb extends ViewApi {

	/**
	 * Load the settings page template.
	 *
	 * @return void
	 */
	public function load_template() {

		$data = [
			'page_title' => 'BWL Advanced FAQ Manager Addons',
			'addons'     => $this->get_addons(),
		];

		$this->render( BAF_VIEWS_DIR . 'Admin/Addons/tpl_addons.php',$data );

	}

	/**
	 * Get the addons data.
	 *
	 * @return array
	 */
	private function get_addons() {
		$doc_repo          = 'https://xenioushk.github.io/docs-plugins-addon/baf-addon/';
		$download_repo     = 'https://bluewindlab.net/product/';
		$static_assets_dir = 'https://xenioushk.github.io/bwl-static-assets/previews/addon/';
		$addons            = [
			[
				'title'    => 'Ajaxified FAQ Search',
				'info'     => 'This add-on enhances the functionality of the FAQ Manager by introducing a quick and efficient way to search for frequently asked questions.',
				'version'  => '1.1.3',
				'doc'      => $doc_repo . 'atfc/index.html',
				'download' => $download_repo . 'ajaxified-faq-search-bwl-advanced-faq-addon',
				'preview'  => $static_assets_dir . 'afs.jpg',
			],

			[
				'title'    => 'FAQ Tab For WooCommerce',
				'info'     => "FAQ Tab For WooCommerce allows you to convert you're FAQ posts in to WooCommerce product FAQ item with in a minute. ",
				'version'  => '1.1.3',
				'doc'      => $doc_repo . 'ftfwc/index.html',
				'download' => $download_repo . 'faq-tab-for-woocommerce-bwl-advanced-faq-manager-addon',
				'preview'  => $static_assets_dir . 'ftfwc.jpg',
			],
		];

		return $addons;
	}
}
