<?php
namespace BwlFaqManager\Callbacks\OptionsPanel\Pages;

use Xenioushk\BwlPluginApi\Api\View\ViewApi;

/**
 * Class for loading the faq sort/category sort templates.
 *
 * @package BwlFaqManager
 * @since: 1.0.0
 * @author: Mahbub Alam Khan
 */
class AdminFaqSortCb extends ViewApi {

	/**
	 * The page title.
	 *
	 * @var string
	 */
	public $page_title;
	/**
	 * The filter page.
	 *
	 * @var string
	 */
	public $baf_filter_page = 'all';

	/**
	 * The sort menu items.
	 *
	 * @var array
	 */
	public $sort_menu_items = [];

	/**
	 * Page Data
	 *
	 * @var array
	 */
	public $page_data = [];

	/**
	 * Load the settings page template.
	 *
	 * @return void
	 */
	public function load_template() {

		$this->set_page();
		$this->set_sort_menu();

		$data = [
			'page_title'      => $this->page_title,
			'page_subtitle'   => $this->get_page_subtitle(),
			'baf_filter_page' => $this->baf_filter_page,
			'sort_menu_items' => $this->sort_menu_items,
			'tpl_partial'     => $this->get_partial_template(),
			'page_data'       => $this->page_data,
		];

		$this->render( BAF_VIEWS_DIR . 'Admin/TaxonomySort/index.php',$data );

	}


	/**
	 * Set the page title and filter.
	 *
	 * @return void
	 */
	private function set_page() {
		$current_page = sanitize_text_field( $_GET['sort_filter'] ?? 'all' ); //phpcs:ignore

		switch ( $current_page ) {
			case 'category':
				$page_title = esc_html__( 'FAQ Sorting By Category', 'bwl-adv-faq' );
				break;
			case 'topics':
				$page_title = esc_html__( 'FAQ Sorting By Topics', 'bwl-adv-faq' );
				break;
			case 'category-sort':
				$page_title = esc_html__( 'Sort FAQ Categories', 'bwl-adv-faq' );
				break;
			default:
				$page_title = esc_html__( 'FAQ Sorting', 'bwl-adv-faq' );
				break;
		}

		$this->page_title      = $page_title;
		$this->baf_filter_page = $current_page;
	}


	/**
	 * Get the page subtitle.
	 *
	 * @return string
	 */
	private function get_page_subtitle() {
		return esc_html__(
            'Sorting FAQ by drag-n-drop. Items at the top will be appear in first.',
            'bwl-adv-faq'
		);
	}

	/**
	 * Set the sort menu.
	 *
	 * @return void
	 */
	private function set_sort_menu() {

		$activeClass = 'sort-selected';
		$sort_page   = admin_url( 'edit.php?post_type=bwl_advanced_faq&page=bwl_advanced_faq_sort' );

		$this->sort_menu_items = [

			[
				'link'         => $sort_page,
				'title'        => esc_html__( 'All FAQs Sorting', 'bwl-adv-faq' ),
				'active_class' => ( $this->baf_filter_page === 'all' ) ? $activeClass : '',
			],
			[
				'link'         => $sort_page . '&sort_filter=category',
				'title'        => esc_html__( 'Category Wise FAQ Sorting', 'bwl-adv-faq' ),
				'active_class' => ( $this->baf_filter_page === 'category' ) ? $activeClass : '',
			],
			[
				'link'         => $sort_page . '&sort_filter=topics',
				'title'        => esc_html__( 'Topics Wise FAQ Sorting', 'bwl-adv-faq' ),
				'active_class' => ( $this->baf_filter_page === 'topics' ) ? $activeClass : '',
			],
			[
				'link'         => $sort_page . '&sort_filter=category-sort',
				'title'        => esc_html__( 'FAQ Category Sort', 'bwl-adv-faq' ),
				'active_class' => ( $this->baf_filter_page === 'category-sort' ) ? $activeClass : '',
			],

		];

	}
	/**
	 * Get the partial template.
	 *
	 * @return string
	 */
	private function get_partial_template() {

		$partial_tpl_url = BAF_VIEWS_DIR . 'Admin/TaxonomySort/sorting-pages/';

		switch ( $this->baf_filter_page ) {
			case 'category':
				$tpl_partial = $partial_tpl_url . 'part-taxonomy-items-sort.php';
                break;
			case 'topics':
				$tpl_partial = $partial_tpl_url . 'part-taxonomy-items-sort.php';
                break;
			case 'category-sort':
				$tpl_partial = $partial_tpl_url . 'part-category-sort.php';

				$options_panel      = admin_url( 'edit.php?post_type=' . BAF_POST_TYPE . '&page=bwl-advanced-faq-settings' );
				$sub_cat_enable_img = "<img src='" . BAF_LIBS_DIR . "screenshots/enable_sub_cat_mode.jpg' / > ";
				$this->page_data    = [
					'content_show' => 0,
					'content_msg'  => sprintf( '<p>✅ Please enable the <strong><a href="%s">Enable Sub Categories Mode?</a></strong> to display this page content!<p/><p><a href="%s">%s</a></p>', $options_panel,$options_panel, $sub_cat_enable_img ),
				];

				if ( BAF_SUB_CAT_ENABLE_STATUS ) {
					$this->page_data = [
						'content_show' => 1,
					];
				}

				break;
			default:
				$tpl_partial = $partial_tpl_url . 'part-all-faq-sort.php';
				break;
		}

		return $tpl_partial;

	}
}
