<?php
namespace BwlFaqManager\Callbacks\ShortcodeEditor;

use BwlFaqManager\Helpers\FaqHelper;

use BwlFaqManager\Traits\CommonTraits;
use BwlFaqManager\Traits\ShortcodeEditorFieldsTraits;
/**
 * Class for plugin shortcode editor callback.
 *
 * @package BwlFaqManager
 */
class PluginScEditorCb {

	use CommonTraits;
	use ShortcodeEditorFieldsTraits;

	/**
	 * Save the installation data.
	 */
	public function display_editor() {

		// WPML FIXING IN VERSION 1.6.6

		if ( defined( 'ICL_SITEPRESS_VERSION' ) ) {

			global $sitepress;
			$current_lang = $sitepress->get_current_language(); // save current language
			$new_lang     = ( get_transient( 'WPML_BAF_SELECTED_LANG' ) != '' ) ? get_transient( 'WPML_BAF_SELECTED_LANG' ) : 'en';
			$sitepress->switch_lang( $new_lang );
		}

			$faq_categories = FaqHelper::get_faq_taxonomies( BAF_TAX_CAT, [ 'hide_empty' => 1 ] );

			$faq_topics = FaqHelper::get_faq_taxonomies( BAF_TAX_TOPIC, [ 'hide_empty' => 1 ] );

		if ( defined( 'ICL_SITEPRESS_VERSION' ) ) {

			$sitepress->switch_lang( $current_lang ); // restore previous language
		}

		?>

<h3>
		<?php

		// echo $_REQUEST['shortcode'] ?? '1'; //phpcs:ignore
		esc_html_e( 'BWL Advanced FAQ Manager Shortcode Editor', 'bwl-adv-faq' );
		?>
    <span class="btn_baf_editor_close">X</span>
</h3>

<div id="baf_editor_popup_content">

    <div class="row">

		<?php
      echo $this->get_shortcode_editor_menu(); //phpcs:ignore
		?>
    </div>

    <hr class="bafm-shortcode-seperator" />

    <div class="row bafm_dn" id="faq_single_container">

		<?php
      echo $this->get_faq_dropdown(); //phpcs:ignore
		?>
    </div>

    <div class="row bafm_dn" id="faq_category_container">

		<?php
      //phpcs:disable
          echo $this->get_select_field(
                  [
                    'name'    => 'faq_category',
                    'id'      => 'faq_category',
                    'title'   => esc_html__( 'FAQ Category', 'bwl-adv-faq' ),
                    'options' => $faq_categories,
                  ]
          ); 
        //phpcs:enable  

		?>

    </div>

    <div class="row bafm_dn" id="faq_item_container">

		<?php
		  echo $this->get_faq_dropdown(); //phpcs:ignore
		?>
    </div>

    <div class="row bafm_dn" id="faq_topics_container">

		<?php
      //phpcs:disable
          echo $this->get_select_field(
                  [
                    'name'    => 'faq_topics',
                    'id'      => 'faq_topics',
                    'title'   => esc_html__( 'FAQ Topics', 'bwl-adv-faq' ),
                    'options' => $faq_topics,
                  ]
          ); 
        //phpcs:enable
		?>

    </div>

    <div class="row bafm_dn" id="faq_tab_container">

    <div class="faq-two-col">
        <label for="bwl_tabify"><?php esc_html_e( 'Show In Tab', 'bwl-adv-faq' ); ?></label>
        <input type="checkbox" id="bwl_tabify" name="bwl_tabify" value="1" class="bafm_checkbox" />
    </div>

    <div class="faq-two-col">

        <label for="bwl_tabify_ver"
        class="text-right"><?php esc_html_e( 'Show Items in Vertical Tab', 'bwl-adv-faq' ); ?></label>
        <input type="checkbox" id="bwl_tabify_ver" name="bwl_tabify_ver" value="1" class="bafm_checkbox" />
    </div>

    </div> <!-- end row  -->

    <div class="row baf_sc_settings">
    <label for="no_of_faqs"><?php esc_html_e( 'Number of FAQs', 'bwl-adv-faq' ); ?></label>
    <input type="text" id="no_of_faqs" name="no_of_faqs" value="" class="baf_input_small" />
    <small><?php esc_html_e( 'e . g: Any number like 1, 2, 3 ', 'bwl-adv-faq' ); ?></small>
    </div>

    <div class="row baf_sc_settings">
		<?php

          //phpcs:disable
          echo $this->get_select_field(
                  [
                    'name'    => 'orderby',
                    'id'      => 'orderby',
                    'title'   => esc_html__( 'Order By', 'bwl-adv-faq' ),
                    'options' => [
                      ''           => esc_html__( '- Select -', 'bwl-adv-faq' ),
                      'ID'         => esc_html__( 'ID', 'bwl-adv-faq' ),
                      'title'      => esc_html__( 'Title', 'bwl-adv-faq' ),
                      'menu_order' => esc_html__( 'Custom Sorting', 'bwl-adv-faq' ),
                      'date'       => esc_html__( 'Date', 'bwl-adv-faq' ),
                      'rand'       => esc_html__( 'Random Order', 'bwl-adv-faq' ),
                    ],
                  ]
          ); 
        //phpcs:enable

		?>
    </div>

    <div class="row baf_sc_settings">
		<?php

          //phpcs:disable
          echo $this->get_select_field(
                  [
                    'name'    => 'order',
                    'id'      => 'order',
                    'title'   => esc_html__( 'Order Type', 'bwl-adv-faq' ),
                    'options' => [
                      ''     => esc_html__( '- Select -', 'bwl-adv-faq' ),
                      'ASC'  => esc_html__( 'Ascending', 'bwl-adv-faq' ),
                      'DESC' => esc_html__( 'Descending', 'bwl-adv-faq' ),
                    ],
                  ]
          ); 
        //phpcs:enable
		?>
    </div>

    <div class="row baf_sc_settings">

    <label for="sbox"><?php esc_html_e( 'Show Search Box', 'bwl-adv-faq' ); ?></label>
    <input type="checkbox" id="sbox" name="sbox" value="1" class="bafm_checkbox" checked="checked" />

    </div> <!-- end row  -->

    <div class="row baf_sc_settings">

    <label for="bwla_form"><?php esc_html_e( 'Add External FAQ Form', 'bwl-adv-faq' ); ?></label>
    <input type="checkbox" id="bwla_form" name="bwla_form" value="1" class="bafm_checkbox" />
		<?php
		echo $this->set_youtube_url( 'https:// youtu.be/L1nXi5AQnwg' );
		?>
    </div> <!-- end row  -->

    <div class="row baf_sc_settings">
    <label for="bwla_pagination"><?php esc_html_e( 'Pagination', 'bwl-adv-faq' ); ?></label>
    <input type="checkbox" id="bwla_pagination" name="bwla_pagination" value="1" class="bafm_checkbox"
        checked="checked" />
    </div> <!-- end row  -->

    <div class="row bafm_dn" id="faq_description_container">
    <label for="bwla_taxonomy_info"><?php esc_html_e( 'Show Description?', 'bwl-adv-faq' ); ?></label>
    <input type="checkbox" id="bwla_taxonomy_info" name="bwla_taxonomy_info" value="1" class="bafm_checkbox" />
    </div> <!-- end row  -->

    <div class="row baf_sc_settings">

		<?php

        echo $this->get_text_field( //phpcs:ignore
            [
                'name'       => 'bwla_item_per_page',
                'id'         => 'bwla_item_per_page',
                'title'      => esc_html__( 'Items Per Page', 'bwl-adv-faq' ),
                'class_name' => 'baf_input_small',
                'value'      => 5,
            ]
        );
		?>
    <small><?php esc_html_e( 'e.g: Any number like 1,2,3 ', 'bwl-adv-faq' ); ?></small>
    </div>

    <div id="baf_editor_popup_buttons">
    <input id="addShortCodebtn" name="addShortCodebtn" class="button-primary" type="button" value="Insert" />
    <input id="closeShortCodebtn" name="closeShortCodebtn" class="button" type="button" value="Close" />
    </div>

</div>

		<?php
		wp_die();
	}

	/**
	 * Get the shortcode editor menu.
	 *
	 * @return string
	 */
	private function get_shortcode_editor_menu() {

		$menu_label = '<label for="custom_faq_type">' . esc_html__( 'FAQ Type', 'bwl-adv-faq' ) . '</label>';

		$menu = [
			'1' => $this->get_radio_btn_field(
				[
					'name'       => 'custom_faq_type',
					'title'      => esc_html__( 'All', 'bwl-adv-faq' ),
					'class_name' => 'custom_faq_type',
					'value'      => 1,
					'checked'    => true,
				]
			),
			'2' => $this->get_radio_btn_field(
				[
					'name'       => 'custom_faq_type',
					'title'      => esc_html__( 'Category', 'bwl-adv-faq' ),
					'class_name' => 'custom_faq_type',
					'value'      => 2,
					'checked'    => false,
				]
			),
			'3' => $this->get_radio_btn_field(
				[
					'name'       => 'custom_faq_type',
					'title'      => esc_html__( 'Topics', 'bwl-adv-faq' ),
					'class_name' => 'custom_faq_type',
					'value'      => 3,
					'checked'    => false,
				]
			),
			'4' => $this->get_radio_btn_field(
				[
					'name'       => 'custom_faq_type',
					'title'      => esc_html__( 'Single FAQ', 'bwl-adv-faq' ),
					'class_name' => 'custom_faq_type',
					'value'      => 4,
					'checked'    => false,
				]
			),
		];

		$menu_output = '';

		foreach ( $menu as $key => $value ) {
			$menu_output .= $value;
		}
		return $menu_label . $menu_output;
	}


	/**
	 * Get all FAQ items.
	 *
	 * @return string
	 */
	private function get_faq_dropdown() {

		$faq_items = [];

		foreach ( FaqHelper::get_all_published_faqs( [ 'orderby' => 'title', 'order' => 'asc' ] ) as $faqs ) :
			$faq_items[ $faqs->ID ] = $faqs->post_title;
		endforeach;

		return $this->get_select_field(
            [
				'name'    => 'faq_items',
				'id'      => 'faq_items',
				'title'   => esc_html__( 'FAQs', 'bwl-adv-faq' ),
				'options' => $faq_items,
			]
		);

	}
}
