<?php
namespace BwlFaqManager\Callbacks\Shortcodes;

use BwlFaqManager\Callbacks\Shortcodes\FaqOutputCb;
use WP_Query;

/**
 * Class FaqItemsCb
 *
 * Handles the FAQ items shortcode callbacks.
 *
 * @package BwlFaqManager
 */
class FaqItemsCb {

	/**
	 * Shortcode attributes.
	 *
	 * @var array
	 */
	private $atts = [];

	/**
	 * Shortcode data.
	 *
	 * @var array
	 */
	private $faq_data = [];

	/**
	 * Shortcode handler for the FAQ items.
	 *
	 * @param array $atts Shortcode attributes.
	 * @return string HTML output for the FAQ items.
	 */
	public function get_faq_items( $atts ) {

		$atts = shortcode_atts([
			'faq_container_id'      => wp_rand(),
			'post_type'             => BAF_POST_TYPE,
			'meta_key'              => '',
			'orderby'               => 'ID',
			'order'                 => 'DESC',
			'limit'                 => -1,
			'faq_category'          => '',
			'faq_topics'            => '',
			'sbox'                  => 1,
			'search_only_title'     => 0,
			'sbox_class'            => '',
			'placeholder'           => esc_html__( 'Search...', 'bwl-adv-faq' ),
			'highlight_color'       => '#000000',
			'highlight_bg'          => '#FDE990',
			'baf_suggestion_status' => 0,
			'baf_suggestion_prefix' => esc_html__( 'Popular searches:', 'bwl-adv-faq' ),
			'baf_suggestion'        => '',
			'cont_ext_class'        => '',
			'btn_ctrl'              => 1,
			'bwl_tabify'            => 0,
			'list'                  => 0, // list=1 enables multiple catgories or topics group
			'multi'                 => 0,
			'single'                => 0,
			'taxonomy_info_search'  => 0,
			'taxonomy_info'         => 0, // It will display taxonomy description.
			'taxonomy_title'        => 1, // 0=hide the taxonomy title
			'collapse'              => 0,
			'fpid'                  => 0, // display mutiple FAQs
			'paginate'              => 0, // enable or disable pagination
			'pag_limit'             => 5,
			'post_ids'              => '',
			'theme_id'              => '', // light, red, blue,green,pink,orange
			'first_color'           => '',
			'second_color'          => '',
			'label_text_color'      => '',
			'accordion_arrow'       => '',
			'custom_layout'         => '', // baf_layout_flat, baf_layout_semi_round, baf_layout_round
			'row_open'              => '', // Mention the row number that you would like to open when load the page.
			'sc_excerpt'            => 0,
			'schema'                => 0,
			'aia'                   => 0,
		], $atts);

		$this->atts = $atts;
		// Extract the attributes.
		extract( $atts ); //phpcs:ignore

		// Meta Key Update.
		if ( $meta_key === 'votes_count' ) {
			$meta_key = 'baf_votes_count';
		}

		if ( intval( $multi ) ) {
			return FaqOutputCb::get_multi_faq_interface( $this->atts );
		}

		// Show Single FAQ. Introduced Version 1.4.9
		if ( $single ) {

			return FaqOutputCb::get_single_faq_interface( $this->atts );
		}

		// New Feature added in version 1.4.6

		if ( intval( $list ) ) {
			if ( ! empty( $faq_category ) || ! empty( $faq_topics ) ) {

				return $this->get_list_faq_interface();

			}
		}

		$taxonomy        = BAF_TAX_CAT;
		$terms           = $faq_category;
		$baf_sort_prefix = PREFIX_BAF_CAT;

		if ( ! empty( $faq_topics ) ) {
			$taxonomy        = BAF_TAX_TOPIC;
			$terms           = $faq_topics;
			$baf_sort_prefix = PREFIX_BAF_TOPIC;
		}

		$args = [
			'post_status'    => 'publish',
			'post_type'      => $post_type,
			'orderby'        => $orderby,
			'order'          => $order,
			'posts_per_page' => $limit,
		];

		// Check if $terms is empty or not before adding to the query.

		if ( ! empty( $terms ) ) {
			$args['tax_query'] = [
				[
					'taxonomy'         => $taxonomy,
					'field'            => 'slug', // 👈 QUERY BY SLUG
					'terms'            => [ $terms ],
					'include_children' => false, // only direct assigned posts
				],
			];
		}

		if ( ! empty( $post_ids ) ) {
			$args['post__in'] = explode( ',', $post_ids );
		}

		if ( ! empty( $meta_key ) ) {
			$args['meta_key'] = $meta_key;
		}
		/**********************************************************
		 * @Description:  If tabbify faq and custom order has been set, then we
		 * need to adjust loop.
		 * @since: Version 1.6.1
		 * ********************************************************* */

		if ( intval( $bwl_tabify ) === 1 && $orderby === 'menu_order' ) {

			$taxonomy_details  = get_term_by( 'slug', $terms, $taxonomy );
			$sorted_posts_data = trim( get_option( $baf_sort_prefix . $taxonomy_details->term_id ) );

			if ( ! empty( $sorted_posts_data ) ) {
				$args['post__in'] = explode( ',', $sorted_posts_data );
				$args['orderby']  = 'post__in';
			}
		}

		$loop = new WP_Query( $args );

		$list_output  = sprintf( '<section class="ac-container" container_id="%s" id="%s">',
			$faq_container_id,
			$faq_container_id,
		);
		$list_output .= FaqOutputCb::get_baf_output( $this->atts, $loop );
		$list_output .= '</section>';

		return $list_output;
	}

	/**
	 * Shortcode handler for the FAQ list.
	 *
	 * @return string HTML output for the FAQ list.
	 */
	public function get_list_faq_interface() {

		// Extract the attributes.
		extract( $this->atts ); //phpcs:ignore

		$unique_faq_container_id = $faq_container_id ?? wp_rand();

		$list_output = sprintf( '<section class="ac-container" container_id="%s" id="%s">',
			$unique_faq_container_id,
			$unique_faq_container_id,
		);

		$list_inner_output = '';

		$orderby   = $orderby ?? 'ID';
		$order     = $order ?? 'DESC';
		$limit     = $limit ?? -1;
		$paginate  = $paginate ?? 0;
		$pag_limit = $pag_limit ?? 5;
		$sbox      = $sbox ?? 1;

		if ( $sbox ) {
			// Added in version 1.7.1
			// Search Only Title
			$search_only_title = $search_only_title ?? 0;
			// Custom Class For Search Box.

			$sbox_extra_class = 'baf_filter_list'; // important class

			if ( ! empty( $sbox_class ) ) {
				$sbox_extra_class .= ' ' . $sbox_class; // add extra space before the custom class.
			}

			$sbox_attributes = [
				'sbox_id'               => $unique_faq_container_id,
				'unique_id'             => $unique_faq_container_id,
				'paginate'              => $paginate,
				'search_only_title'     => $search_only_title,
				'taxonomy_info_search'  => $taxonomy_info_search,
				'sbox_class'            => $sbox_extra_class,
				'pag_limit'             => $pag_limit,
				'placeholder'           => $placeholder,
				'highlight_color'       => $highlight_color,
				'highlight_bg'          => $highlight_bg,
				'baf_suggestion_status' => $baf_suggestion_status,
				'baf_suggestion_prefix' => $baf_suggestion_prefix,
				'baf_suggestion'        => $baf_suggestion,
				'btn_ctrl'              => $btn_ctrl,
				'cont_ext_class'        => $cont_ext_class,
			];

			// Build the shortcode attributes string manually with double quotes.
			$sbox_shortcode_atts_string = '';
			foreach ( $sbox_attributes as $key => $value ) {
				$sbox_shortcode_atts_string .= sprintf( '%s="%s" ', esc_attr( $key ), esc_attr( $value ) );
			}

			// Generate the final shortcode string.
			$shortcode_tag    = 'baf_sbox';
			$shortcode_string = sprintf( '[%s %s/]', esc_attr( $shortcode_tag ), trim( $sbox_shortcode_atts_string ) );

			$list_inner_output .= do_shortcode( $shortcode_string );
		}

		$taxonomy_type = ( ! empty( $faq_topics ) ) ? 'topics' : 'category';
		$faq_taxonomy  = ( ! empty( $faq_topics ) ) ? explode( ',', $faq_topics ) : explode( ',', $faq_category );

		foreach ( $faq_taxonomy as $topics ) {

			$taxonomy_details = get_term_by( 'slug', $topics, "advanced_faq_{$taxonomy_type}" );

			if ( $taxonomy_details ) {

				// 1. First level Taxonomy.
				// Default Fields.
				$this->faq_data = [
					'title'                 => $taxonomy_details->name,
					'description'           => $taxonomy_details->description,
					'shortcode'             => 'bwla_dsort_faq',
					'orderby'               => $orderby,
					'taxonomy_type'         => $taxonomy_type,
					'slug'                  => $topics, // taxonomy slug.
					'faq_' . $taxonomy_type => $topics,  // The taxonomy_type and slug will generate faq_taxonomy_type value.
					'sbox'                  => 0,
					'sbox_class'            => $sbox_class,
					'search_only_title'     => $search_only_title,
					'btn_ctrl'              => $btn_ctrl,
					'order'                 => $order,
					'pag_limit'             => $pag_limit,
					'paginate'              => $paginate,
					'limit'                 => $limit,
					'theme_id'              => $theme_id,
					'first_color'           => $first_color,
					'second_color'          => $second_color,
					'label_text_color'      => $label_text_color,
					'accordion_arrow'       => $accordion_arrow,
					'custom_layout'         => $custom_layout,
					'sc_excerpt'            => $sc_excerpt,
					'schema'                => $schema,
				];

				if ( $orderby === 'menu_order' ) {

					$this->faq_data['shortcode']       = 'bwla_dsort_faq';
					$this->faq_data['baf_sort_filter'] = $taxonomy_type;
					$this->faq_data['baf_term_id']     = $taxonomy_details->term_id;

				} else {

					$this->faq_data['shortcode'] = 'bwla_faq';
					$this->faq_data['list']      = 0; // This is super important.
				}
			} else {

				// Remove that slug from the array.
				$faq_taxonomy = array_diff( $faq_taxonomy, [ $topics ] );

			}
		}

		$list_output .= $list_inner_output;

		// recursively print the categories.
		$list_output .= $this->display_taxonomies_recursive( $faq_taxonomy );

		$list_output .= '</section>';

		return $list_output;
	}

	/**
	 * Recursively print the taxonomies.
	 *
	 * @param array $faq_taxonomy The taxonomy items.
	 * @param int   $depth The current depth of recursion.
	 * @return string HTML output for the taxonomies.
	 */
	private function display_taxonomies_recursive( $faq_taxonomy, $depth = 0 ) {

		$output = '';

		foreach ( $faq_taxonomy as $taxonomy ) {

			$taxonomy_details = get_term_by( 'slug', $taxonomy, 'advanced_faq_category' );
			$post_count       = $taxonomy_details->count ?? 0;

			if ( $post_count > 0 ) {

				$this->faq_data['title']        = $taxonomy_details->name ?? '';
				$this->faq_data['description']  = $taxonomy_details->description ?? '';
				$this->faq_data['list']         = 0;
				$this->faq_data['slug']         = $taxonomy_details->slug; // taxonomy slug.
				$this->faq_data['faq_category'] = $taxonomy; // The taxonomy_type and slug will generate faq_taxonomy_type value.
				$this->faq_data['sbox']         = 0; // The taxonomy_type and slug will generate faq_taxonomy_type value.

				// Menu Order
				$this->faq_data['baf_term_id'] = $taxonomy_details->term_id;

				// $output .= str_repeat( '--', $depth ) . ' ' . $taxonomy . ' (D: ' . $depth . ')<br>';
			$output .= $this->generate_term_shortcode(); //phpcs:ignore

				$child_terms = get_terms([
                    'taxonomy'   => BAF_TAX_CAT,
                    'hide_empty' => true,
                    'parent'     => $taxonomy_details->term_id,
                    // 'orderby'    => 'term_order',
				]);

				if ( is_array( $child_terms ) && ! empty( $child_terms ) ) {
					$childs = [];
					foreach ( $child_terms as $child_term ) {

						$childs[] = $child_term->slug;
					}
					$output .= $this->display_taxonomies_recursive( $childs, $depth + 1 );
				}
			}
		}
		return $output;
	}

	/**
	 * Generate the shortcode for the term.
	 *
	 * @return string HTML output for the term posts.
	 */
	private function generate_term_shortcode() {

		// Extract the attributes.
		extract( $this->faq_data ); //phpcs:ignore

		$tax_title = sprintf( '<h2>%s</h2>', esc_html( $title ) );
		$tax_desc  = ( ! empty( $description ) ) ? sprintf( '<p class="baf_taxonomy_info">%s</p>', esc_html( $description ) ) : '';

		// Excluding the title and description from the shortcode attributes.
		$shortcode_attributes = array_diff_key(
			$this->faq_data,
			array_flip(
				[
					'title',
					'description',
					'shortcode',
				]
			)
		);

		// Build the shortcode attributes string manually with double quotes.
		$attributes_string = '';
		foreach ( $shortcode_attributes as $key => $value ) {
				$attributes_string .= sprintf( '%s="%s" ', esc_attr( $key ), esc_attr( $value ) );
		}

		// Generate the final shortcode string.
		$shortcode_string = sprintf( '[%s %s/]', esc_attr( $shortcode ), trim( $attributes_string ) );

		$list_info_container = sprintf( '<div class="baf_taxonomy_info_container">%s%s</div>', $tax_title, $tax_desc );

		$output = $list_info_container . do_shortcode( $shortcode_string );
		return $output;
	}
}
