<?php
namespace BwlFaqManager\Callbacks\Shortcodes;

use BwlFaqManager\Helpers\FaqColorScheme;
use BwlFaqManager\Controllers\Votes\FaqVoteContainer;
use BwlFaqManager\Helpers\FaqHelper;
use BwlFaqManager\Helpers\PluginConstants;

use WP_Query;

/**
 * Class for faq shortcode output callback.
 *
 * @package BwlFaqManager
 * @since 1.6.1
 */
class FaqOutputCb {

	/**
	 * Get the output of the FAQ interface.
	 *
	 * @param array  $atts Attributes for the shortcode.
	 * @param object $loop The loop object.
	 * @param string $id_prefix The prefix for the ID.
	 * @return string The output of the FAQ interface.
	 */
	public static function get_baf_output( $atts, $loop, $id_prefix = '' ) {

		global $post;

		// Fixed in version 1.6.6
		extract( $atts ); // phpcs:ignore

		$options = PluginConstants::$plugin_options;

		if ( isset( $theme_id ) && ! empty( $theme_id ) ) {

			$theme_id = $theme_id;
		} elseif ( isset( $options['bwl_advanced_faq_theme'] ) ) {

			$enable_custom_theme = $options['enable_custom_theme'] ?? 0;
			$theme_id            = $enable_custom_theme ? 'custom' : $options['bwl_advanced_faq_theme'] ?? 'default';

		} else {

			$theme_id = 'default';
		}
		$predefined_themes = ( new FaqColorScheme() )->baf_get_theme_color_scheme( $theme_id );

		// Initialize Data.

		$unique_faq_container_id = $faq_container_id ?? wp_rand();
		$sbox                    = $sbox ?? 1;
		$search_only_title       = $search_only_title ?? 0;
		$placeholder             = $placeholder ?? esc_html__( 'Search...', 'bwl-adv-faq' );
		$baf_suggestion_status   = $baf_suggestion_status ?? 0;
		$baf_suggestion_prefix   = $baf_suggestion_prefix ?? '';
		$baf_suggestion          = $baf_suggestion ?? '';
		$highlight_color         = $highlight_color ?? '';
		$highlight_bg            = $highlight_bg ?? '';
		$cont_ext_class          = $cont_ext_class ?? '';
		$sbox_class              = $sbox_class ?? '';
		$pag_limit               = $pag_limit ?? 5;
		$paginate                = $paginate ?? 0;
		$baf_section_class       = ( isset( $custom_layout ) && ! empty( $custom_layout ) ) ? "ac-container {$custom_layout}" : 'ac-container';

		// For Custom Theme Color.
		// Deafult Gradient First Color.

		$first_color = $first_color ?? $predefined_themes['first_color'] ?: $predefined_themes['first_color'];

		// Deafult Gradient Second Color.
		$second_color = $second_color ?? $predefined_themes['second_color'] ?: $predefined_themes['second_color'];
		// Deafult Gradient Second Color.
		$label_text_color = $label_text_color ?? $predefined_themes['label_text_color'] ?: $predefined_themes['label_text_color'];
		// Accordion Arrow.
		$default_accordion_arrow = ( isset( $options['bwl_advanced_fa_arrow_up'] ) && $options['bwl_advanced_fa_arrow_up'] != '' ) ? substr( $options['bwl_advanced_fa_arrow_up'], 1, strlen( $options['bwl_advanced_fa_arrow_up'] ) ) : 'f106';  // From Settings Page.
		// From Shortcode.
		// Deafult Gradient Second Color.
		$baf_accordion_arrow = ( isset( $accordion_arrow ) && $accordion_arrow != '' ) ? $accordion_arrow : $default_accordion_arrow;

		if ( ! empty( $faq_category ) ) {
			$id_prefix = 'category-';
		} elseif ( ! empty( $faq_topics ) ) {
			$id_prefix = 'topic-';
		} elseif ( $id_prefix == 'single-' ) {
			$id_prefix          = 'single-';
			$collapse_status    = ( isset( $collapse ) && $collapse == 1 ) ? ' baf-single-collapse' : '';
			$baf_section_class .= ' single-faq-post' . $collapse_status;
			$sbox               = 0;
		} else {
			$id_prefix = wp_rand();
		}

		// Start Generating FAQ Output.

		$section_faq_unique_class = 'section_baf_' . $unique_faq_container_id;
		$tag_row_open             = '';

		if ( isset( $row_open ) && ! empty( $row_open ) ) {
			$section_faq_unique_class .= ' baf_row_open ';
			$tag_row_open             .= 'data-row_open="' . $row_open . '"';
		}

		// AIA.

		$baf_section_class .= ( isset( $aia ) && $aia == 1 ) ? ' aia_container' : '';
		$output             = '';

		/*------ Get Options For Search Settings  ---------*/

		$search_status = $options['bwl_advanced_faq_search_status'] ?? 1;

		if ( $search_status && $sbox != 0 ) {

			$sbox_shortcode_tag        = 'baf_sbox';
			$sbox_shortcode_attributes = [
				'sbox_id'               => $unique_faq_container_id,
				'unique_id'             => $unique_faq_container_id,
				'placeholder'           => $placeholder,
				'paginate'              => $paginate,
				'sbox_class'            => $sbox_class,
				'search_only_title'     => $search_only_title,
				'pag_limit'             => $pag_limit,
				'baf_suggestion_status' => $baf_suggestion_status,
				'baf_suggestion_prefix' => $baf_suggestion_prefix,
				'baf_suggestion'        => $baf_suggestion,
				'highlight_color'       => $highlight_color,
				'highlight_bg'          => $highlight_bg,
				'cont_ext_class'        => $cont_ext_class,
			];

			$sbox_shortcode_string = '';
			foreach ( $sbox_shortcode_attributes as $key => $value ) {
					$sbox_shortcode_string .= sprintf( '%s="%s" ', esc_attr( $key ), esc_attr( $value ) );
			}

			$sbox_shortcode = sprintf( '[%s %s/]', esc_attr( $sbox_shortcode_tag ), trim( $sbox_shortcode_string ) );

			$output .= do_shortcode( $sbox_shortcode );
		}

		$section_attributes = [
			'class'                 => "baf_custom_style {$section_faq_unique_class} {$baf_section_class}",
			'container_id'          => $unique_faq_container_id,
			'data-first_color'      => $first_color,
			'data-second_color'     => $second_color,
			'data-label_text_color' => $label_text_color,
			'data-accordion_arrow'  => $baf_accordion_arrow,
			'data-row_open'         => $tag_row_open,
			'data-schema'           => $schema,
		];

		$section_attributes_string = '';
		foreach ( $section_attributes as $key => $value ) {
				$section_attributes_string .= sprintf( '%s="%s" ', esc_attr( $key ), esc_attr( $value ) );
		}

		$output .= sprintf( '<section %s>',$section_attributes_string ); // Open the container

		$btn_ctrl = $options['bwl_collapsible_btn_status'] ?? 0;

		if ( $btn_ctrl ) {

			$btn_ctrl_atts = [
				'expand'      => 'plus',
				'collapsible' => 'minus',
			];

			$btn_ctrl_string = '';
			foreach ( $btn_ctrl_atts as $key => $value ) {
				$btn_ctrl_string .= '<span class="baf-' . $key . '-all"><i class="fa fa-' . $value . '"></i></span>';
			}

			$output .= sprintf( '<div class="baf-ctrl-btn">%s</div>',$btn_ctrl_string );
		}

		/*------ FAQ Meta ---------*/

		$meta_info_status = intval( $options['bwl_advanced_faq_meta_info_status'] ?? 0 );

		$bwl_advanced_faq_meta_info = '';
		$faq_date_time_info         = '';

		/*------ FAQ Author ---------*/

		$author_info = '';

		/*------ Post Edit ---------*/

		$faq_edit_status    = ( is_user_logged_in() && current_user_can( 'edit_post', $post->ID ) ) ? 1 : 0;
		$faq_edit_interface = '';

		/*------ Like Button ---------*/

		$faq_vote_container = '';

		$faq_vote_button_status = $options['bwl_advanced_faq_like_button_status'] ?? 1;

		/* ----- Logged In Requirement ---- */

		if ( isset( $options['baf_logged_in_voting_status'] ) && $options['baf_logged_in_voting_status'] == 1 ) {

			if ( ! is_user_logged_in() ) {

				$faq_vote_button_status = 0;
			}
		}

		if ( $loop->have_posts() ) {

			$counter = 0;

			while ( $loop->have_posts() ) :

				$loop->the_post();
				$post_id = get_the_ID();

				if ( $faq_vote_button_status ) {
					$faq_vote_container = ( new FaqVoteContainer() )->get_the_vote_container( $post_id );
				}
				// Get Author FAQ Author Information
				$author_info = "<span class='fa fa-user'></span> " . do_shortcode( '[bwla_author]' );

				// Likes Count.
				$votesCount  = intval( get_post_meta( $post_id, 'baf_votes_count', true ) );
				$votesLayout = '<span class="fa fa-thumbs-up"></span>' . $votesCount;

				// Views Count.
				$viewsCount  = intval( get_post_meta( $post_id, 'baf_views_count', true ) );
				$viewsLayout = '<span class="fa fa-eye"></span>' . $viewsCount;

				// Get FAQ Date and Time
				$faq_date_time_info = "<span class='fa fa-calendar'></span> " . get_the_date();

				// Get FAQ Edit Link
				if ( $faq_edit_status == 1 && current_user_can( 'edit_post', $post_id ) ) {
					$bwl_advanced_faq_edit_url = get_edit_post_link();
					$faq_edit_interface        = '<span class="fa fa-edit"></span> <a href="' . $bwl_advanced_faq_edit_url . '" target="_blank" title="' . get_the_title() . '">' . esc_html__( 'Edit', 'bwl-adv-faq' ) . '</a>';
				}

				// Initialize ingredient customizer addon option.
				$baf_ic_info = '';

				if ( shortcode_exists( 'baf_ic_products' ) ) {
					global $post;
					$backup                     = $post;
					$bwl_advanced_faq_meta_info = '';
					$baf_ic_info               .= do_shortcode( '[baf_ic_products f_id="' . $post_id . '"]' );
					$post                       = $backup;
				}

				if ( $meta_info_status === 1 ) {

					$bwl_advanced_faq_meta_info = "<div class='bwl_meta_info'>" . $author_info . ' ' . $votesLayout . ' ' . $viewsLayout . ' ' . $faq_date_time_info . ' ' . $faq_edit_interface . '</div>';
				}

				$bwl_advanced_faq_meta_info .= $baf_ic_info;

				$faqTitleTag = $options['bwl_advanced_label_tag'] ?? 'label';
				// empty, null, or false.
				$title   = get_the_title();
				$output .= '<div class="bwl-faq-container bwl-faq-container-' . $unique_faq_container_id . '" id="faq-' . $post_id . '">' .
				'<' . $faqTitleTag . ' class="baf_schema" label_id="ac-' . $id_prefix . $post_id . '" parent_container_id="' . $unique_faq_container_id . '">' . $title . '</' . $faqTitleTag . '>' .
				'<input id="ac-' . $id_prefix . $unique_faq_container_id . $post_id . '" name="accordion-1" type="checkbox">' .
				'<article class="ac-medium" article_id="ac-' . $id_prefix . $post_id . '">' . FaqHelper::get_faq_excerpt( $sc_excerpt ) . $bwl_advanced_faq_meta_info . $faq_vote_container . '</article>' .
				'</div>';

				++$counter;

			endwhile;

			$paginattion_status = ( $counter > $pag_limit ) ? 1 : 0;

			if ( $paginattion_status && $paginate ) {
				$output .= '<input type="hidden" id="current_page"><input type="hidden" id="show_per_page">';
				$output .= sprintf(
					"<div id='baf_page_navigation' class='baf_page_navigation' data-paginate='%s' data-pag_limit='%s'></div>",
					$paginattion_status,
					$pag_limit
				);
			}
		}

		$output .= '</section>'; // Close the container

		wp_reset_postdata();

		return $output;
	}

	/**
	 * Get layout for multiple FAQs
	 *
	 * @param array $atts Attributes for the shortcode.
	 * @return string The output of the FAQ interface.
	 */
	public static function get_multi_faq_interface( $atts ) {

		shortcode_atts([
			'limit'        => -1,
			'meta_key'     => '',
			'faq_category' => '',
			'faq_topics'   => '',
			'sbox'         => 0,
			'bwl_tabify'   => 0,
			'list'         => 0,
			'fpid'         => 0,
			'collapse'     => 0,
			'sc_excerpt'   => 0,
			'schema'       => 0,
		], $atts);

		// Extract the attributes.
		extract( $atts ); // phpcs:ignore

		$args = [
			'post_status'    => 'publish',
			'post_type'      => BAF_POST_TYPE,
			'posts_per_page' => -1,
		];

		$fpids = explode( ',', $fpid );

		if ( is_array( $fpids ) ) {
			$args['post__in'] = $fpids;
		}

		if ( isset( $meta_key ) && ! empty( $meta_key ) ) {
			$args['meta_key'] = $meta_key;
		}

		$id_prefix = 'multi-';

		$loop = new WP_Query( $args );

		return self::get_baf_output( $atts, $loop, $id_prefix );
	}

	/**
	 * Get single FAQ interface
	 *
	 * @param array $atts Attributes for the shortcode.
	 * @return string The output of the FAQ interface.
	 */
	public static function get_single_faq_interface( $atts ) {

		shortcode_atts([
			'limit'        => -1,
			'meta_key'     => '',
			'faq_category' => '',
			'faq_topics'   => '',
			'sbox'         => 0,
			'bwl_tabify'   => 0,
			'list'         => 0,
			'single'       => 1,
			'fpid'         => 0,
			'collapse'     => 0,
			'sc_excerpt'   => 0,
			'schema'       => 0,
		], $atts);

		// Extract the attributes.
		extract( $atts ); // phpcs:ignore

		$args = [
			'post_status'    => 'publish',
			'post_type'      => BAF_POST_TYPE,
			'posts_per_page' => 1,
			'p'              => $fpid,
		];

		if ( ! empty( $meta_key ) ) {
			$args['meta_key'] = $meta_key;
		}

		$id_prefix = 'single-';

		$loop = new WP_Query( $args );

		return self::get_baf_output( $atts, $loop, $id_prefix );
	}
}
