<?php
namespace BwlFaqManager\Callbacks\Shortcodes;

/**
 * Class for FAQ Search Box.
 *
 * @package BwlFaqManager
 */
class FaqSearchBoxCb {

	/**
	 * Get the suggestions for the FAQ search box.
	 *
	 * @param array $atts Shortcode attributes.
	 * @return string HTML output for the suggestion string.
	 */
	private function get_suggestions( $atts ) {

		extract( $atts ); //phpcs:ignore

		$baf_suggestion_string = '';

		if ( $baf_suggestion_status && ! empty( $baf_suggestion ) ) {

			$baf_suggestion = explode( ',', $baf_suggestion );

			if ( count( $baf_suggestion ) === 0 ) {
				return '';
			}

			$custom_baf_suggestion = '';

			foreach ( $baf_suggestion as $value ) {
				$custom_baf_suggestion .= '<a href="#">' . $value . '</a>, ';
			}

			$custom_baf_suggestion = substr( $custom_baf_suggestion, 0, strlen( $custom_baf_suggestion ) - 2 );

			$baf_suggestion_string .= '<div class="baf_suggestion"><b class="baf_suggestion_prefix">' . $baf_suggestion_prefix . '</b> ' . $custom_baf_suggestion . '</div>';
		}

		return $baf_suggestion_string;
	}

	/**
	 * Shortcode handler for the FAQ search box.
	 *
	 * @param array $atts Shortcode attributes.
	 * @return string HTML output for the FAQ search box.
	 */
	public function get_faq_search_box( $atts ) {

		$atts = shortcode_atts([
            'sbox_id'               => wp_rand(),
            'unique_id'             => '',
            'paginate'              => 0,
            'search_only_title'     => 0,
            'taxonomy_info_search'  => 0,
            'sbox_class'            => '',
            'pag_limit'             => 0,
            'placeholder'           => esc_html__( 'Search...', 'bwl - adv - faq' ),
            'highlight_color'       => '// 000000',
            'highlight_bg'          => '#FDE990',
            'baf_suggestion_status' => 0,
            'baf_suggestion_prefix' => esc_html__( 'Popular searches:', 'bwl-adv-faq' ),
            'baf_suggestion'        => '',
            'cont_ext_class'        => '',
		], $atts);

		// Extract the attributes.
		extract( $atts ); //phpcs:ignore

		$unique_faq_container_id = $sbox_id;

		$baf_suggestion_string = $this->get_suggestions( $atts );

		$bwla_search_form_class = ( isset( $cont_ext_class ) && $cont_ext_class != '' ) ? 'bwl-faq-search-panel ' . $cont_ext_class : 'bwl-faq-search-panel';

		$uniqueIdTag = ( ! empty( $unique_id ) ) ? "data-unique_id={$unique_id}" : '';

		$taxonomyInfoSearchTag = $taxonomy_info_search == 1 ? " data-taxonomy_info_search='{$taxonomy_info_search}'" : '';

		$formIdTag = $taxonomy_info_search == 0 ? 'data-form_id="' . $unique_faq_container_id . '"' : '';

		$baf_sbox_output = '<form id="live-search" action="#" class="' . $bwla_search_form_class . '" method="post" data-paginate="' . $paginate . '" data-search_only_title="' . $search_only_title . '" data-pag_limit="' . $pag_limit . '" ' . $uniqueIdTag . ' ' . $formIdTag . '>
                        <fieldset>
                            <input type="text" class="search_icon text-input baf_filter_list ' . $sbox_class . '" id="bwl_filter_' . $unique_faq_container_id . '" value="" placeholder="' . $placeholder . '" data-highlight_color="' . $highlight_color . '" data-highlight_bg="' . $highlight_bg . '" ' . $taxonomyInfoSearchTag . '>
                                <span class="baf-btn-clear baf_dn"></span>
                                <span id="bwl-filter-message-' . $unique_faq_container_id . '" class="bwl-filter-message"></span>
                        </fieldset>
                        ' . $baf_suggestion_string . '
                    </form>';

		return $baf_sbox_output;
	}
}
