<?php
namespace BwlFaqManager\Callbacks\Shortcodes;

use BwlFaqManager\Callbacks\Shortcodes\FaqOutputCb;
use WP_Query;
/**
 * Class Faq Dynamic Sorted List Cb
 *
 * @package BwlFaqManager
 */
class FaqSortedListCb {

	/**
	 * Get the sorted list of FAQs.
	 *
	 * @param array $atts Shortcode attributes.
	 *
	 * @return string HTML output of the sorted list.
	 */
	public function get_faq_sorted_list( $atts ) {

		$atts = shortcode_atts([
			'meta_key'          => '',
			'orderby'           => 'ID',
			'order'             => 'ASC',
			'limit'             => -1,
			'faq_category'      => '',
			'faq_topics'        => '',
			'baf_sort_filter'   => 'category',
			'baf_term_id'       => 0,
			'paginate'          => 0,
			'pag_limit'         => 5,
			'sbox'              => 0,
			'sbox_class'        => 0,
			'search_only_title' => 0,
			'sc_excerpt'        => 0,
			'schema'            => 0,
		], $atts);

		// Extract the attributes.
		extract($atts); //phpcs:ignore

		$taxonomy        = BAF_TAX_CAT;
		$terms           = [ $faq_category ];
		$baf_sort_prefix = PREFIX_BAF_CAT;

		if ( $baf_sort_filter === 'topics' ) {
			$taxonomy        = BAF_TAX_TOPIC;
			$terms           = [ $faq_topics ];
			$baf_sort_prefix = PREFIX_BAF_TOPIC;
		}

		$args = [
			'post_status' => 'publish',
			'post_type'   => BAF_POST_TYPE,
			'tax_query'   => [
				[
					'taxonomy'         => $taxonomy,
					'field'            => 'slug', // 👈 QUERY BY SLUG
					'terms'            => $terms,
					'include_children' => false, // only direct assigned posts
				],
			],
		];

		// Get the sorted posts data from options.
		// 🚨 $sorted_posts_data is super important.
		$sorted_posts_data = trim( get_option( $baf_sort_prefix . $baf_term_id ) );

		if ( ! empty( $sorted_posts_data ) ) {
			$args['post__in'] = explode( ',', $sorted_posts_data );
			$args['orderby']  = 'post__in';
		}

		$loop = new WP_Query( $args );

		return FaqOutputCb::get_baf_output( $atts, $loop );
	}
}
