<?php
namespace BwlFaqManager\Controllers\Cpt;

/**
 * Custom Columns
 *
 * @package BwlFaqManager
 */
class CustomColumns {

	/**
     * Register the column filters.
     */
    public function register() {
        add_action( 'admin_init', [ $this, 'initialize' ] );
    }

    /**
     * Initialize column actions.
     */
    public function initialize() {
        add_filter( 'manage_' . BAF_POST_TYPE . '_posts_columns', [ $this, 'columns_header' ] );
        add_action( 'manage_' . BAF_POST_TYPE . '_posts_custom_column', [ $this, 'columns_content' ] );
    }

    /**
     * Add custom columns to the post type.
     *
     * @param array $columns The columns.
     *
     * @return array
     */
    public function columns_header( $columns ) {

        $columns['baf_votes_count'] = esc_html__( 'Likes', 'bwl-adv-faq' );

        $columns['baf_views_count'] = esc_html__( 'Views', 'bwl-adv-faq' );

        return $columns;
    }

	/**
     * Add content to the custom columns.
     *
     * @param string $column The column.
     */
    public function columns_content( $column ) {

        global $post;

        switch ( $column ) {

            case 'baf_votes_count':
                $votesCount = get_post_meta( $post->ID, 'baf_votes_count', true );

                $votesCount = ( ! empty( $votesCount ) ) ? $votesCount : 0;

                if ( $votesCount != 0 ) {
                    echo '<a href=' . admin_url( "edit.php?page=bwl-advanced-faq-analytics&post_type=bwl_advanced_faq&filter_type=likes&date_range=30&faq_id={$post->ID}" ) . ">{$votesCount}</a>";
                } else {
                    echo $votesCount;
                }

                break;

            case 'baf_views_count':
                $viewsCount = get_post_meta( $post->ID, 'baf_views_count', true );

                $viewsCount = ( ! empty( $viewsCount ) ) ? $viewsCount : 0;

                if ( $viewsCount != 0 ) {
                    echo '<a href=' . admin_url( "edit.php?page=bwl-advanced-faq-analytics&post_type=bwl_advanced_faq&filter_type=views&date_range=30&faq_id={$post->ID}" ) . ">{$viewsCount}</a>";
                } else {
                    echo $viewsCount;
                }

                break;
        }
    }
}


// new BafCptCustomColumns();
