<?php

namespace BwlFaqManager\Controllers\Notices;

use BwlFaqManager\Callbacks\Notices\NoticeCb;
use Xenioushk\BwlPluginApi\Api\Notices\NoticesApi;
use BwlFaqManager\Callbacks\Notices\NoticeBlocks\OfferNoticeBlockCb;
use BwlFaqManager\Callbacks\Notices\NoticeBlocks\AddonNoticeBlockCb;
use BwlFaqManager\Callbacks\Notices\NoticeBlocks\LicenseNoticeBlockCb;
use BwlFaqManager\Callbacks\Notices\NoticeBlocks\YoutubeNoticeBlockCb;

/**
 * Class PluginNotices
 *
 * This class handles the registration of the plugin admin notices.
 *
 * @since: 1.1.1
 * @package BwlFaqManager
 */
class PluginNotices {

	/**
	 * Notice callback.
	 *
	 * @var notice_cb
	 */
	private $notice_cb;

	/**
	 * Register PluginNotices.
	 */
	public function register() {

		add_action( 'admin_init', [ $this, 'initialize' ] );

	}

	/**
	 * Initialize PluginNotices.
	 */
	public function initialize() {

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}
		// Initialize API.
		$notices_api = new NoticesApi();

		// Initialize callbacks.
		$this->notice_cb = new NoticeCb();

		$notices_api->add_notices( $this->get_notices() )->register();
	}

	/**
	 * Get the notices.
	 *
	 * @return array
	 */
	private function get_notices() {

		// All the notices will use the same callback.
		$notice_callback = [ $this->notice_cb, 'get_the_notice' ];

		// Register notices.
		$notice_classes = [
			AddonNoticeBlockCb::class,
			YoutubeNoticeBlockCb::class,
			LicenseNoticeBlockCb::class,
			OfferNoticeBlockCb::class,
		];

		$notices = array_map(
            function ( $class_name ) use ( $notice_callback ) {
                return [
                    'callback' => $notice_callback,
                    'notice'   => ( new $class_name() )->get_the_notice(),
                ];
            },$notice_classes
        );

		return $notices;
	}
}
