<?php
namespace BwlFaqManager\Controllers\OptionsPanel;

use BwlFaqManager\Callbacks\OptionsPanel\Pages\AdminFaqSortCb;
use BwlFaqManager\Callbacks\OptionsPanel\Pages\AddonsPageCb;
use BwlFaqManager\Callbacks\OptionsPanel\Pages\AboutPluginPageCb;
use BwlFaqManager\Callbacks\OptionsPanel\Pages\AnalyticsPageCb;
use BwlFaqManager\Callbacks\OptionsPanel\Pages\LicensePageCb;

/**
 * Class SettingsMenu
 *
 * @package BwlFaqManager
 * @since 1.0.0
 * @author Mahbub Alam Khan
 */
class SettingsMenu {

    /**
     * Register the settings menu.
     */
    public function register() {

        add_action( 'admin_menu', [ $this, 'register_menu_pages' ] );
    }

    /**
     * Get the sub menu pages.
     *
     * @return array
     */
    public function get_the_sub_menu_pages() {

        $license_activation_info = ( BAF_PRODUCT_VERIFIED_STATUS == 1 ) ?
        [ 'class' => 'activated', 'text' => esc_attr__( 'ACTIVE', 'bwl-adv-faq' ) ] :
        [ 'class' => 'inactive', 'text' => esc_attr__( 'INACTIVE', 'bwl-adv-faq' ) ];

        $subMenus = [
            [
                'page_title' => esc_attr__( 'Advanced FAQ Sort Page', 'bwl-adv-faq' ),
                'menu_title' => BAF_S_FAQ_TEXT . ' ' . esc_attr__( 'Sorting', 'bwl-adv-faq' ),
                'menu_slug'  => 'bwl_advanced_faq_sort',
                'cb'         => [ ( new AdminFaqSortCb() ), 'load_template' ],
            ],
            [
                'page_title' => esc_attr__( 'Analytics BWL Advanced FAQ Manager', 'bwl-adv-faq' ),
                'menu_title' => esc_attr__( 'Analytics', 'bwl-adv-faq' ),
                'menu_slug'  => 'bwl-advanced-faq-analytics',
                'cb'         => [ ( new AnalyticsPageCb() ), 'load_template' ],
            ],
            [
                'page_title' => esc_attr__( 'License Page', 'bwl-adv-faq' ) . ' | ' . BAF_PLUGIN_TITLE,
                'menu_title' => esc_attr__( 'License', 'bwl-adv-faq' ) . '<span class="baf-license-activation-tag ' . $license_activation_info['class'] . '">' . $license_activation_info['text'] . '</span>',
                'menu_slug'  => 'baf-license',
                'cb'         => [ ( new LicensePageCb() ), 'load_template' ],
            ],
            [
                'page_title' => esc_attr__( 'BWL Advanced FAQ Manager Addons', 'bwl-adv-faq' ),
                'menu_title' => esc_attr__( 'Addons', 'bwl-adv-faq' ) . '<span class="baf-license-activation-tag activated">Free</span>',
                'menu_slug'  => 'baf-addons',
                'cb'         => [ ( new AddonsPageCb() ), 'load_template' ],
            ],
            [
                'page_title' => esc_attr__( 'About BWL Advanced FAQ Manager Plugin', 'bwl-adv-faq' ),
                'menu_title' => esc_attr__( 'About Plugin', 'bwl-adv-faq' ),
                'menu_slug'  => 'bwl-advanced-faq-welcome',
                'cb'         => [ ( new AboutPluginPageCb() ), 'load_template' ],
            ],

        ];

        return $subMenus;
    }

    /**
     * Register the sub menu pages.
     */
    public function register_menu_pages() {

        $baf_options_menu_link = 'edit.php?post_type=' . BAF_POST_TYPE;

        foreach ( $this->get_the_sub_menu_pages() as $sub_page ) {
            add_submenu_page(
                $baf_options_menu_link,
                $sub_page['page_title'],
                $sub_page['menu_title'],
                'manage_options',
                $sub_page['menu_slug'],
                $sub_page['cb'],
                $sub_page['position'] ?? null
            );
        }
    }
}
