<?php

namespace BwlFaqManager\Controllers\Votes;

use BwlFaqManager\Helpers\PluginConstants;

/**
 * Class FaqVoteStatus
 *
 * @package BwlFaqManager
 */
class FaqVoteStatus {

	/**
	 * Check if the user has already voted for the FAQ.
	 *
	 * @param int $post_id Post ID.
	 *
	 * @return bool
	 */
	public function get_faq_vote_status( $post_id ) {

		$options            = PluginConstants::$plugin_options;
		$time_before_revote = ( isset( $options['baf_repeat_vote_interval'] ) &&
		is_numeric( $options['baf_repeat_vote_interval'] ) &&
		$options['baf_repeat_vote_interval'] > 0 ) ? $options['baf_repeat_vote_interval'] : 120; // = 2 hours

		// Retrieve post votes IPs
		$meta_IP = get_post_meta( $post_id, 'baf_voted_IP' );

		$baf_vote_count = intval( get_post_meta( $post_id, 'baf_votes_count', true ) );

		if ( $baf_vote_count === 0 ) {
			return false;
		}

		if ( ! empty( $meta_IP ) ) {

			$baf_voted_IP = $meta_IP[0];
		} else {

			$baf_voted_IP = [];
		}

		// Retrieve current user IP
		$ip = $_SERVER['REMOTE_ADDR'];

		// If user has already voted
		if ( in_array( $ip, array_keys( $baf_voted_IP ),true ) ) {

			$time = $baf_voted_IP[ $ip ];

			$now = time();

			// Compare between current time and vote time

			if ( round( ( $now - $time ) / 60 ) > $time_before_revote ) {

				return false;
			}

			return true;
		}

		return false;
	}
}
