<?php
namespace BwlFaqManager\Helpers;

use BwlFaqManager\Helpers\PluginConstants;

/**
 * Class for Custom Theme Style integrate for FAQ.
 *
 * @package BwlFaqManager
 * @since 1.6.7
 * @author Mahbub Alam Khan
 */
class FaqColorScheme {

	/**
	 * Theme color scheme for FAQ.
     *
     * @param string $theme_id Theme ID.
	 * @example: If $preset value is 1, then we're going to skip $enable_custom_theme value.
	 **/
	public function baf_get_theme_color_scheme( $theme_id ) {

		switch ( $theme_id ) {

			case 'light':
				$gradient_first_color    = '#F7F7F7';
				$gradient_second_color   = '#FAFAFA';
				$active_background_color = '#F7F7F7';
				$label_text_color        = '#555555';
				$hover_background        = '#FFFFFF';
				$label_hover_text_color  = '#3a3a3a';
				$tab_top_border          = '#2C2C2C';
				break;

			case 'red':
				$gradient_first_color    = '#FF3019';
				$gradient_second_color   = '#CF0404';
				$active_background_color = '#CF0404';
				$label_text_color        = '#FFFFFF';
				$hover_background        = '#FF3019';
				$label_hover_text_color  = '#FFFFFF';
				$tab_top_border          = $gradient_first_color;
				break;

			case 'blue':
				$gradient_first_color    = '#49C0F0';
				$gradient_second_color   = '#2CAFE3';
				$active_background_color = '#2CAFE3';
				$label_text_color        = '#FFFFFF';
				$hover_background        = '#49C0F0';
				$label_hover_text_color  = '#FFFFFF';
				$tab_top_border          = $gradient_first_color;
				break;

			case 'green':
				$gradient_first_color    = '#0EB53D';
				$gradient_second_color   = '#299A0B';
				$active_background_color = '#299A0B';
				$label_text_color        = '#FFFFFF';
				$hover_background        = '#0EB53D';
				$label_hover_text_color  = '#FFFFFF';
				$tab_top_border          = $gradient_first_color;
				break;

			case 'pink':
				$gradient_first_color    = '#FF5DB1';
				$gradient_second_color   = '#EF017C';
				$active_background_color = '#EF017C';
				$label_text_color        = '#FFFFFF';
				$hover_background        = '#FF5DB1';
				$label_hover_text_color  = '#FFFFFF';
				$tab_top_border          = $gradient_first_color;
				break;

			case 'orange':
				$gradient_first_color    = '#FFA84C';
				$gradient_second_color   = '#FF7B0D';
				$active_background_color = '#FF7B0D';
				$label_text_color        = '#FFFFFF';
				$hover_background        = '#FFA84C';
				$label_hover_text_color  = '#FFFFFF';
				$tab_top_border          = $gradient_first_color;
				break;

			case 'custom':
				$options                 = PluginConstants::$plugin_options;
				$hover_background        = '#FFA84C';
				$gradient_first_color    = $options['gradient_first_color'] ?? '#FFA84C';
				$gradient_second_color   = $options['gradient_second_color'] ?? '#FF7B0D';
				$label_text_color        = $options['label_text_color'] ?? '#777777';
				$label_hover_text_color  = $options['label_hover_text_color'] ?? '#777777';
				$active_background_color = $options['active_background_color'] ?? '#FF7B0D';
				$tab_top_border          = $gradient_first_color;
				$hover_background        = $gradient_first_color;
				break;
			default:
				$theme_id = 'default';
				// DEFAULT COLOR SCHEME.
				$tab_top_border          = '#2C2C2C';
				$gradient_first_color    = '#FFFFFF';
				$gradient_second_color   = '#EAEAEA';
				$active_background_color = '#C6E1EC';
				$label_text_color        = '#777777';
				$hover_background        = '#FFFFFF';
				$label_hover_text_color  = '#777777';
		}

		return [
			'theme_id'         => $theme_id,
			'first_color'      => $gradient_first_color,
			'second_color'     => $gradient_second_color,
			'label_text_color' => $label_text_color,
		];
	}
}
