<?php
namespace BwlFaqManager\Helpers;

use BwlFaqManager\Helpers\PluginConstants;

/**
 * Class for FAQ helper functions
 *
 * @package BwlFaqManager
 * @since 1.0.0
 */
class FaqHelper {

    /**
     * Get all the published FAQs.
     *
     * @param array $args Arguments for the query.
     * @return array
     */
    public static function get_all_published_faqs( $args = [] ) {

        $default_args = [
            'post_type'      => BAF_POST_TYPE,
            'post_status'    => 'publish',
            'orderby'        => 'ID',
            'order'          => 'DESC',
            'posts_per_page' => -1,
        ];

        $args = array_merge(
            $default_args,
            $args
        );

        return get_posts( $args );
    }

    /**
     * Change The Default WordPress Excerpt Length.
     *
     * @param int $status exceprt status.
     * @return string
     */
	public static function get_faq_excerpt( $status = 0 ) {

		$options = PluginConstants::$plugin_options;

		if ( $status === 1 ) {
			$options['bwl_advanced_faq_excerpt_status'] = 1;
		}

		if ( isset( $options['bwl_advanced_faq_excerpt_status'] ) && $options['bwl_advanced_faq_excerpt_status'] == 1 ) {

			$content = get_the_content();

			if ( str_word_count( $content ) > $options['bwl_advanced_faq_excerpt_length'] ) {

				$baf_excerpt_read_more = apply_filters( 'baf_excerpt_read_more_text', esc_html__( 'Read More', 'bwl-adv-faq' ) . ' &raquo;' );

				$trimmed_content = wp_trim_words( $content, $options['bwl_advanced_faq_excerpt_length'], '..... <a class="read-more" href="' . esc_url( get_permalink( get_the_ID() ) ) . '">' . $baf_excerpt_read_more . ' </a>' );
			} else {

				$trimmed_content = str_replace( ']]>', ']]&gt;', apply_filters( 'the_content', get_the_content() ) );
			}

			$content = $trimmed_content;
		} else {

			$content = str_replace( ']]>', ']]&gt;', apply_filters( 'the_content', get_the_content() ) );
		}

		$content = '<div class="baf_content">' . apply_filters( 'baf_force_content_shortcode', $content ) . '</div>';

		return $content;
	}

    /**
	 * Get all FAQ Taxonomies.
	 *
     * @param string $taxonomy Taxonomy name.
	 * @param array  $args Arguments for the query.
	 *
	 * @return array List of taxonomies.
	 */
	public static function get_faq_taxonomies( $taxonomy = BAF_TAX_CAT, $args = [] ) {
		$default_args = [
			'taxonomy'     => $taxonomy,
			'hide_empty'   => 0,
			'orderby'      => apply_filters( 'baf_tax_orderby', BAF_SUB_CAT_ENABLE_STATUS ? 'term_order' : 'title' ),
			'order'        => 'ASC',
			'hierarchical' => 0,
			'hide_sub_cat' => 1,
		];
		$args         = array_merge( $default_args, $args );

		// Get categories and filter to include only top-level categories.
		$categories = get_categories( $args );

		if ( $args['hide_sub_cat'] ) {
			$categories_array = array_filter( $categories, function ( $category ) {
				return $category->parent === 0; // Only include top-level categories.
			});
		}

		// Convert objects to arrays and include the total post count.
		$categories_array = array_map( function ( $category ) {
			return [
				'term_id' => $category->term_id,
				'name'    => $category->name,
				'slug'    => $category->slug,
				'count'   => $category->count, // Total count of posts in the category.
			];
		}, $categories_array ?? $categories );

		return $categories_array;

	}
}
