<?php

namespace BwlFaqManager\Widgets;

use WP_Widget;

/**
 * Class for Display FAQs Widget
 *
 * @package BwlFaqManager
 */
class FaqsWidget extends WP_Widget {

    /**
	 * Constructor
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		parent::__construct(
            'bwl_advanced_faq_manager_widget',
            'Advanced FAQs',
            [
				'classname'   => 'Bwl_Advanced_Faq_Manager_Widget',
				'description' => esc_html__( 'Display FAQ Lists In Main sidebar or footer sidebar', 'bwl-adv-faq' ),
            ]
		);
	}

    /**
	 * Create the widget form.
     *
     * @param array $instance widget instance.
     * @return void
     * @since 1.0.0
     */
    public function form( $instance ) {

        $defaults = [
            'title'                              => esc_html__( 'FAQ', 'bwl-adv-faq' ),
            'bwl_advanced_faq_manager_shortcode' => '[bwla_faq]',
        ];

        $instance = wp_parse_args( (array) $instance, $defaults );

        extract( $instance );

		?>


<p>
    <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'FAQ', 'bwl-adv-faq' ); ?></label>
    <input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
    name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>" />
</p>

<p>
    <label for="<?php echo $this->get_field_id( 'bwl_advanced_faq_manager_shortcode' ); ?>">
		<?php esc_html_e( 'FAQ Shortcode', 'bwl-adv-faq' ); ?>
    </label>
    <textarea id="<?php echo $this->get_field_id( 'bwl_advanced_faq_manager_shortcode' ); ?>"
    name="<?php echo $this->get_field_name( 'bwl_advanced_faq_manager_shortcode' ); ?>" cols="30" rows="3"
    class="widefat"><?php echo esc_attr( $bwl_advanced_faq_manager_shortcode ); ?></textarea>

</p>

<div class="baf-sc-hints">
    <ol>
    <li>
        <p>Display Random FAQ:</p>
        <small>[bwla_faq orderby='rand' /]</small>
    </li>
    <li>
        <p>Display Top Voted FAQs:</p>
        <small>[bwla_faq meta_key='votes_count' orderby='meta_value_num' order='DESC'/]</small>
    </li>
    <li>
        <p>Display Excerpt:</p>
        <small>[bwla_faq sc_excerpt=1/]</small>
    </li>
    </ol>
</div>

		<?php

    }

    /**
	 * Update the widget data.
     *
     * @param array $new_instance new widget instance.
     * @param array $old_instance old widget instance.
     * @return $instance
     * @since 1.0.0
     */
    public function update( $new_instance, $old_instance ) {

        $instance = $old_instance;

        $instance['title'] = sanitize_title( $new_instance['title'] );

        $instance['bwl_advanced_faq_manager_shortcode'] = sanitize_textarea_field( $new_instance['bwl_advanced_faq_manager_shortcode'] );

        return $instance;
    }


    /**
	 * Output the widget.
     *
     * @param array $args widget arguments.
     * @param array $instance widget instance.
     * @return void
     * @since 1.0.0
     */
    public function widget( $args, $instance ) {

        extract( $args );

        $title = apply_filters( 'widget-title', $instance['title'] );

        $shortcode = $instance['bwl_advanced_faq_manager_shortcode'];
        // phpcs:disable
        echo $before_widget;

        echo ! empty( $title ) ? $before_title . esc_html( $title ) . $after_title : '';
        echo ! empty( $shortcode ) ? do_shortcode( $shortcode ) : ''; 

        echo $after_widget;
        // phpcs:disable
    }
}
