;(function ($) {
  $(function () {
    /*--  FAQ SORTING JS  --*/

    if ($("#baf_faq_sorting_container")) {
      var $btnBafSaveSorting = $("#baf_save_sorting")
      var $btnBafSaveSortingText = $btnBafSaveSorting.val()

      $btnBafSaveSorting.attr("data-term_id", 0)

      // Save Sorting Data.

      function baf_save_sort_data(args) {
        const { filter_type, sort_data, term_id, action_callback } = args

        const data = {
          action: action_callback, // this is the name of our WP AJAX function that we'll set up next
          baf_sort_filter_type: filter_type,
          baf_sort_data: sort_data,
          baf_term_id: term_id,
          taxonomy: BafAdminData.baf_tax_cat,
          _ajax_nonce: BafAdminData.baf_nonce,
        }

        return $.ajax({
          type: "POST",
          url: BafAdminData.ajaxurl,
          data,
          dataType: "JSON",
        })
      }

      // Get Sort Data.

      function baf_get_sorting_data(baf_category_slug, baf_term_id) {
        return $.ajax({
          type: "POST",
          url: BafAdminData.ajaxurl,
          data: {
            action: "baf_get_sorting_data", // this is the name of our WP AJAX function that we'll set up next
            baf_category_slug: baf_category_slug,
            baf_term_id: baf_term_id,
            baf_sort_filter: $btnBafSaveSorting.data("sort_filter"),
          },
          dataType: "JSON",
        })
      }

      /*---- Initializing ----*/

      var $baf_msg_container = $("#baf_faq_sorting_container").find("#sort-status")
      var $baf_sort_subtitle = $baf_msg_container.data("sort_subtitle")
      var $bwl_faq_items = $("#baf_faq_sorting_container").find("#bwl_faq_items")

      if ($bwl_faq_items.find("li").length) {
        $bwl_faq_items.sortable({})
      }

      // Category Wise Sorting.

      if ($("#baf_sort_faq_taxonomy").length) {
        $btnBafSaveSorting.attr("disabled", "disabled")

        var $baf_sort_faq_taxonomy = $("#baf_sort_faq_taxonomy")
        $baf_sort_faq_taxonomy.val("")

        $baf_sort_faq_taxonomy.on("change", function () {
          $btnBafSaveSorting.attr("disabled", "disabled")

          if ($baf_sort_faq_taxonomy.val() == "") {
            $btnBafSaveSorting.removeAttr("data-term_id")
            $bwl_faq_items.html("")
            return ""
          }

          $baf_msg_container.html(BafAdminData.baf_text_loading)

          var baf_category_slug = $(this).val(),
            baf_term_id = $("#baf_sort_faq_taxonomy option:selected").attr("data-term_id")

          $.when(baf_get_sorting_data(baf_category_slug, baf_term_id)).done(function (response_data) {
            if (response_data.status == 1) {
              $baf_msg_container.html($baf_sort_subtitle)
              $btnBafSaveSorting.attr("data-term_id", baf_term_id)

              var output = ""

              $.each(response_data.data, function (index, data) {
                output += '<li id="' + data["post_id"] + '" class="menu-item">' + '<dl class="menu-item-bar">' + '<dt class="menu-item-handle">' + '<span class="menu-item-title">' + data["post_title"] + "</span>" + "</dt>" + "</dl>" + '<ul class="menu-item-transport"></ul>' + "</li>"
              })

              $bwl_faq_items.html(output)

              setTimeout(function () {
                if ($bwl_faq_items.find("li").length) {
                  $bwl_faq_items.sortable({})

                  $btnBafSaveSorting.removeAttr("disabled")
                }
              }, 500)
            } else {
              $baf_msg_container.html($baf_sort_subtitle)
              $btnBafSaveSorting.attr("disabled", "disabled")
            }
          })
        })
      } else {
        $btnBafSaveSorting.removeAttr("disabled")
      }

      /*---- Sorting Data Save Event ----*/

      const getNestedSortableData = function (element) {
        const getChildren = (el) => {
          const children = []
          el.querySelectorAll(":scope > ul > li").forEach((li) => {
            children.push({
              id: li.dataset.id,
              children: getChildren(li),
            })
          })
          return children
        }

        const data = []
        element.querySelectorAll(":scope > li").forEach((li) => {
          data.push({
            id: li.dataset.id,
            children: getChildren(li),
          })
        })
        return data
      }

      const getCategorySortData = function () {
        return getNestedSortableData(document.getElementById("categories-sortable"))
      }

      $btnBafSaveSorting.on("click", function () {
        const $this = $(this)
        $btnBafSaveSorting.val(BafAdminData.baf_text_saving).attr("disabled", "disabled")

        const filter_type = $this.data("sort_filter")
        const args = {
          filter_type,
          term_id: $this.data("term_id") ?? 0,
        }

        if (filter_type == "category-sort") {
          args.sort_data = JSON.stringify(getCategorySortData())
          args.action_callback = "baf_save_category_order"
        } else {
          args.sort_data = $bwl_faq_items.sortable("toArray").toString()
          args.action_callback = "baf_save_sorting_data"
        }

        $.when(baf_save_sort_data(args)).done(function (response_data) {
          const { data } = response_data
          if (data.status == 1) {
            $btnBafSaveSorting.val(BafAdminData.baf_text_saved)

            setTimeout(function () {
              $btnBafSaveSorting.val($btnBafSaveSortingText).removeAttr("disabled")
            }, 2000)
          }
        })
      })
    }
  })
})(jQuery)
